@@ -22,8 +22,8 @@ package Password::Policy::Exception::Pwned;
  
 use parent 'Password::Policy::Exception';
 
-our $VERSION = '0.00_01';
+our $VERSION = '0.00_02';
 
-sub error { return 'This password has been pwned'; }
+sub error { return 'The specified password has been pwned'; }
 
 1;
